@@ -1,5 +1,5 @@
-tbl <- iris[1, ] %>%
-  rtf_body() %>%
+tbl <- iris[1, ] |>
+  rtf_body() |>
   rtf_title("title")
 teststr <- attr(tbl, "rtf_title")
 
@@ -7,8 +7,8 @@ test_that("test if title is converted to RTF correctly", {
   expect_snapshot_output(as_rtf_paragraph(teststr))
 })
 
-tbl <- iris[1, ] %>%
-  rtf_body() %>%
+tbl <- iris[1, ] |>
+  rtf_body() |>
   rtf_footnote("footnote")
 teststr <- attr(tbl, "rtf_footnote")
 
@@ -16,8 +16,8 @@ test_that("test if footnote is converted to RTF correctly", {
   expect_snapshot_output(as_rtf_paragraph(teststr))
 })
 
-tbl <- iris[1, ] %>%
-  rtf_body() %>%
+tbl <- iris[1, ] |>
+  rtf_body() |>
   rtf_source("source")
 teststr <- attr(tbl, "rtf_source")
 
